@@ -175,13 +175,21 @@ def validate_submission(submission, protocol=None):
         LOGGER.exception("problems with scenarios in submission")
         raise_error = True
 
-    try:
-        out = convert_units_to_rcmip_units(submission, protocol_variables)
-        LOGGER.info("succesfully converted units")
-    except ProtocolConsistencyError:
-        LOGGER.exception("problems converting units in submission")
+    if "climate_model" not in submission.meta:
+        LOGGER.exception("no climate_model metadata included in submission")
         raise_error = True
 
+    if "unit" not in submission.meta:
+        LOGGER.exception("no unit metadata included in submission")
+        raise_error = True
+    else:
+        try:
+            out = convert_units_to_rcmip_units(submission, protocol_variables)
+            LOGGER.info("succesfully converted units")
+        except ProtocolConsistencyError:
+            LOGGER.exception("problems converting units in submission")
+            raise_error = True
+
     if raise_error:
         raise ProtocolConsistencyError(
             "submission is inconsistent with the RCMIP protocol"
